diff libpurple/media.h @ 26310:17929a84c1fb

Change purple_media_candidates_prepared to use wildcards.
author Mike Ruprecht <maiku@soc.pidgin.im>
date Thu, 19 Mar 2009 22:57:53 +0000
parents e411aad4346b
children 2ad89aff8d68
line wrap: on
line diff
--- a/libpurple/media.h	Thu Mar 19 22:08:21 2009 +0000
+++ b/libpurple/media.h	Thu Mar 19 22:57:53 2009 +0000
@@ -607,14 +607,16 @@
 					const gchar *name, GList *codecs);
 
 /**
- * Returns whether or not the candidates for a remote user are prepared
+ * Returns whether or not the candidates for set of streams are prepared
  *
  * @param media The media object to find the remote user in.
  * @param name The remote user to check for.
  *
- * @return @c TRUE All streams for the remote user have candidates prepared, @c FALSE otherwise.
+ * @return @c TRUE All streams for the given session_id/participant combination have candidates prepared, @c FALSE otherwise.
  */
-gboolean purple_media_candidates_prepared(PurpleMedia *media, const gchar *name);
+gboolean purple_media_candidates_prepared(PurpleMedia *media,
+		const gchar *session_id, const gchar *participant);
 
 /**
  * Sets the send codec for the a session.
@@ -607,14 +607,16 @@
  *
  * @param media The media object to find the remote user in.
- * @param name The remote user to check for.
+ * @param session_id The session id of the session to check.
+ * @param participant The remote user to check for.
  *